# Planning Transformations for SAP Solutions
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/planning-transformations-for-sap-solutions#introduction)
  * [Planning Transformations for Suggested SAP Solutions](https://help.sap.com/docs/leanix/ea/planning-transformations-for-sap-solutions#planning-transformations-for-suggested-sap-solutions)


Link business capabilities to reference catalog items to view suggested SAP solutions and automatically plan transformations with SAP LeanIX Architecture and Road Map Planning.
